@@ -11,9 +11,9 @@ testthat::test_that(
     set.seed(123)
     using_function1 <-
       statsExpressions::expr_anova_robust(
-        data = dplyr::sample_frac(tbl = statsExpressions::movies_long, size = 0.5),
-        x = genre,
-        y = "length",
+        data = mtcars,
+        x = cyl,
+        y = "wt",
         paired = FALSE,
         k = 5,
         tr = 0.00025,
@@ -28,29 +28,29 @@ testthat::test_that(
           NULL,
           italic("F"),
           "(",
-          "8",
+          "2",
           ",",
-          "201.17562",
+          "18.97383",
           ") = ",
-          "30.46450",
+          "20.24946",
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "2e-05",
           ", ",
           widehat(italic(xi)),
           " = ",
-          "0.56962",
+          "0.95933",
           ", CI"["95%"],
           " [",
-          "0.48190",
+          "0.84565",
           ", ",
-          "0.58374",
+          "1.00154",
           "]",
           ", ",
           italic("n")["obs"],
           " = ",
-          790L
+          32L
         )
       )
 
@@ -91,7 +91,7 @@ testthat::test_that(
           ", ",
           widehat(italic(xi)),
           " = ",
-          "0.1415",
+          "0.1352",
           ", CI"["99%"],
           " [",
           "-0.0284",
